@@ -25,14 +25,25 @@ class AbstractCanvasTool(ToolTemplate):
 
 	def __init__(self, tool_id, label, icon_name, window, **kwargs):
 		super().__init__(tool_id, label, icon_name, window)
+		self.implements_panel = True
 		self.menu_id = 1
 		self.centered_box = None
 		self.needed_width_for_long = 0
 		self.accept_selection = True
 
-	def on_tool_selected(self, *args):
-		super().on_tool_selected()
-		self.apply_to_selection = self.selection_is_active()
+	def adapt_to_window_size(self, available_width):
+		if self.centered_box is None:
+			return
+		if self.centered_box.get_orientation() == Gtk.Orientation.HORIZONTAL:
+			self.needed_width_for_long = self.apply_btn.get_allocated_width() + \
+			                      self.centered_box.get_preferred_width()[0] + \
+			                               self.cancel_btn.get_allocated_width()
+		if self.needed_width_for_long > 0.8 * available_width:
+			self.centered_box.set_orientation(Gtk.Orientation.VERTICAL)
+		else:
+			self.centered_box.set_orientation(Gtk.Orientation.HORIZONTAL)
+
+	############################################################################
 
 	def give_back_control(self, preserve_selection):
 		if not preserve_selection and self.selection_is_active():
@@ -102,36 +113,4 @@ class AbstractCanvasTool(ToolTemplate):
 	def on_draw(self, area, cairo_context):
 		pass # TODO FIXME pour l'instant pas d'overlay quand on modifie la sélection
 
-	def get_deformed_surface(self, source_surface, p_xx, p_yx, p_xy, p_yy, p_x0, p_y0):
-		source_w = source_surface.get_width()
-		source_h = source_surface.get_height()
-		# w = p_xx * source_w + p_xy * 0 + p_x0
-		# h = p_yx * 0 + p_yy * source_h + p_y0
-		normal_w = p_xx * source_w + p_xy * source_h + p_x0
-		normal_h = p_yx * source_w + p_yy * source_h + p_y0
-		# w = abs( p_xx * source_w ) + abs( p_xy * source_h ) + p_x0
-		# h = abs( p_yx * source_w ) + abs( p_yy * source_h ) + p_y0
-
-		# print('source_w, source_h', source_w, source_h)
-		# print('normal_w, normal_h', normal_w, normal_h)
-		# print('p_x0, p_y0', p_x0, p_y0 )
-
-		# w = max(w, source_w) + p_x0
-		# h = max(h, source_h) + p_y0
-
-		w = max(normal_w, source_w + p_x0)
-		h = max(normal_h, source_h + p_y0) # FIXME non toujours pas ?
-
-		new_surface = cairo.ImageSurface(cairo.Format.ARGB32, int(w), int(h))
-		cairo_context = cairo.Context(new_surface)
-		# m = cairo.Matrix(xx=1.0, yx=0.0, xy=0.0, yy=1.0, x0=0.0, y0=0.0)
-		m = cairo.Matrix(xx=p_xx, yx=p_yx, xy=p_xy, yy=p_yy, x0=p_x0, y0=p_y0)
-		cairo_context.transform(m)
-		cairo_context.set_source_surface(source_surface, 0, 0)
-		# FIXME scroll and zoom ?
-		cairo_context.paint()
-		return new_surface
-
-	############################################################################
-################################################################################
 
