@@ -33,7 +33,6 @@ class DrawingSelectionManager():
 		self.l_popover = Gtk.Popover.new_from_model(self.image.window.notebook, menu_l)
 
 	def init_pixbuf(self):
-		# print('⇒ init pixbuf')
 		self.selection_pixbuf = GdkPixbuf.Pixbuf.new(GdkPixbuf.Colorspace.RGB, True, 8, 1, 1)
 
 		self.set_coords(True, 0, 0)
@@ -58,10 +57,8 @@ class DrawingSelectionManager():
 		cairo_context.set_operator(cairo.Operator.DEST_IN)
 		cairo_context.new_path()
 		cairo_context.append_path(self.selection_path)
-		if self.temp_path is None: # XXX condition utile?? on dirait bien
+		if self.temp_path is None: # XXX condition utile??
 			self._set_temp_path(cairo_context.copy_path())
-		# else:
-		# 	print('selection manager ligne 63')
 		cairo_context.fill()
 		cairo_context.set_operator(cairo.Operator.OVER)
 
@@ -109,7 +106,6 @@ class DrawingSelectionManager():
 		if use_import_param:
 			self.is_imported_data = is_imported_data
 		self.temp_path = None
-		# print('⇒ set pixbuf')
 		self.selection_pixbuf = pixbuf
 		self._create_path_from_pixbuf(not self.is_imported_data)
 
@@ -117,7 +113,6 @@ class DrawingSelectionManager():
 		return self.selection_pixbuf
 
 	def reset(self):
-		# print('⇒ reset pixbuf')
 		self.selection_pixbuf = None
 		self.selection_path = None
 		self.set_coords(True, 0, 0)
@@ -132,6 +127,7 @@ class DrawingSelectionManager():
 		if self.temp_path is None:
 			return
 		if not self.is_active:
+			# self.image.window.prompt_message(True, "delete_temp called while `is_active` is False")
 			return
 		cairo_context = cairo.Context(self.image.get_surface())
 		cairo_context.new_path()
@@ -141,13 +137,12 @@ class DrawingSelectionManager():
 		cairo_context.paint()
 		cairo_context.set_operator(cairo.Operator.OVER)
 
-	def get_path_with_scroll(self):
+	def get_path_with_scroll(self, scroll_x, scroll_y):
 		if self.selection_path is None:
 			return None
-		# XXX and the zoom? TODO
 		cairo_context = cairo.Context(self._get_surface())
-		delta_x = 0 - self.image.scroll_x + self.selection_x - self.temp_x
-		delta_y = 0 - self.image.scroll_y + self.selection_y - self.temp_y
+		delta_x = 0 - scroll_x + self.selection_x - self.temp_x
+		delta_y = 0 - scroll_y + self.selection_y - self.temp_y
 		for pts in self.selection_path:
 			if pts[1] is not ():
 				x = pts[1][0] + delta_x
@@ -156,18 +151,6 @@ class DrawingSelectionManager():
 		cairo_context.close_path()
 		return cairo_context.copy_path()
 
-	def correct_coords(self, x1, x2, y1, y2, with_selection_coords):
-		x1 -= self.image.scroll_x
-		x2 -= self.image.scroll_x
-		y1 -= self.image.scroll_y
-		y2 -= self.image.scroll_y
-		if with_selection_coords:
-			x1 += self.selection_x
-			x2 += self.selection_x
-			y1 += self.selection_y
-			y2 += self.selection_y
-		return x1, x2, y1, y2
-
 	def show_selection_on_surface(self, cairo_context, with_scroll):
 		if self.selection_pixbuf is None:
 			return
