@@ -3,14 +3,14 @@
 from gi.repository import Gtk, Gdk
 import cairo
 
-from .abstract_classic_tool import AbstractClassicTool
+from .abstract_tool import ToolTemplate
 from .utilities import utilities_add_arrow_triangle
 
-class ToolArc(AbstractClassicTool):
+class ToolArc(ToolTemplate):
 	__gtype_name__ = 'ToolArc'
 
 	def __init__(self, window, **kwargs):
-		super().__init__('arc', _("Curve"), 'tool-arc-symbolic', window)
+		super().__init__('arc', _("Arc"), 'tool-arc-symbolic', window)
 		self.use_size = True
 
 		self.add_tool_action_enum('line_shape', 'round')
@@ -34,8 +34,23 @@ class ToolArc(AbstractClassicTool):
 			self.selected_end_id = cairo.LineCap.ROUND
 			self.selected_shape_label = _("Round")
 
+	def set_active_operator(self):
+		state_as_string = self.get_option_value('cairo_operator')
+		if state_as_string == 'difference':
+			self.selected_operator = cairo.Operator.DIFFERENCE
+			self.selected_operator_label = _("Difference")
+		elif state_as_string == 'source':
+			self.selected_operator = cairo.Operator.SOURCE
+			self.selected_operator_label = _("Source color")
+		elif state_as_string == 'clear':
+			self.selected_operator = cairo.Operator.CLEAR
+			self.selected_operator_label = _("Eraser")
+		else:
+			self.selected_operator = cairo.Operator.OVER
+			self.selected_operator_label = _("Classic")
+
 	def get_options_label(self):
-		return _("Curve options")
+		return _("Arc options")
 
 	def get_edition_status(self): # TODO l'opérateur est important
 		self.use_dashes = self.get_option_value('use_dashes')
@@ -56,10 +71,14 @@ class ToolArc(AbstractClassicTool):
 		self.x_press = 0.0
 		self.y_press = 0.0
 
-	def on_press_on_area(self, event, surface, event_x, event_y):
-		self.set_common_values(event)
+	def on_press_on_area(self, event, surface, tool_width, left_color, right_color, event_x, event_y):
 		self.x_press = event_x
 		self.y_press = event_y
+		self.tool_width = tool_width
+		if event.button == 1:
+			self.main_color = left_color
+		if event.button == 3:
+			self.main_color = right_color
 
 	def on_motion_on_area(self, event, surface, event_x, event_y):
 		self.restore_pixbuf()
@@ -69,10 +88,10 @@ class ToolArc(AbstractClassicTool):
 			cairo_context.line_to(event_x, event_y)
 		else:
 			cairo_context.move_to(self.wait_points[0], self.wait_points[1])
-			cairo_context.curve_to(self.wait_points[2], self.wait_points[3], self.x_press, self.y_press, event_x, event_y)
-
+			cairo_context.curve_to(self.wait_points[2], self.wait_points[3], \
+			                       self.x_press, self.y_press, event_x, event_y)
 		self._path = cairo_context.copy_path()
-		operation = self.build_operation(event_x, event_y, True)
+		operation = self.build_operation(event_x, event_y)
 		self.do_tool_operation(operation)
 
 	def on_release_on_area(self, event, surface, event_x, event_y):
@@ -87,16 +106,15 @@ class ToolArc(AbstractClassicTool):
 			self.wait_points = (-1.0, -1.0, -1.0, -1.0)
 
 		self._path = cairo_context.copy_path()
-		operation = self.build_operation(event_x, event_y, False)
+		operation = self.build_operation(event_x, event_y)
 		self.apply_operation(operation)
 		self.x_press = 0.0
 		self.y_press = 0.0
 
-	def build_operation(self, event_x, event_y, is_preview):
+	def build_operation(self, event_x, event_y):
 		operation = {
 			'tool_id': self.id,
 			'rgba': self.main_color,
-			'is_preview': is_preview,
 			'operator': self.selected_operator,
 			'line_width': self.tool_width,
 			'line_cap': self.selected_end_id,
@@ -115,6 +133,7 @@ class ToolArc(AbstractClassicTool):
 			return
 		self.restore_pixbuf()
 		cairo_context = cairo.Context(self.get_surface())
+		cairo_context.set_operator(operation['operator'])
 		cairo_context.set_line_cap(operation['line_cap'])
 		#cairo_context.set_line_join(operation['line_join'])
 		line_width = operation['line_width']
@@ -124,17 +143,14 @@ class ToolArc(AbstractClassicTool):
 		if operation['use_dashes']:
 			cairo_context.set_dash([2*line_width, 2*line_width])
 		cairo_context.append_path(operation['path'])
-
-		self.stroke_with_operator(operation['operator'], cairo_context, \
-		                                    line_width, operation['is_preview'])
+		cairo_context.stroke()
 
 		if operation['use_arrow']:
 			x_press = operation['x_press']
 			y_press = operation['y_press']
 			x_release = operation['x_release']
 			y_release = operation['y_release']
-			utilities_add_arrow_triangle(cairo_context, x_release, y_release, \
-			                                       x_press, y_press, line_width)
+			utilities_add_arrow_triangle(cairo_context, x_release, y_release, x_press, y_press, line_width)
 
 	############################################################################
 ################################################################################
